﻿using Syncfusion.XForms.PopupLayout;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using Xamarin.Forms;
using Xamarin.Forms.Xaml;

namespace Popup_Demo
{
	[XamlCompilation(XamlCompilationOptions.Compile)]
	public partial class MyDemoPage : ContentPage
	{
		public MyDemoPage ()
		{
			InitializeComponent ();
		}

        private void Button_Clicked(object sender, EventArgs e)
        {
            Debug.WriteLine("Navigating to main page due to button click on demo page");
            this.Navigation.PushAsync(new MainPage());
        }

        protected override void OnAppearing()
        {
            Debug.WriteLine("Demo page appearing, showing message box");
            base.OnAppearing();
            this.ShowMessageBox("SfPopupLayout from Demo Page", "Done");
        }

        public void ShowMessageBox(
                                   string sMessage,
                                   string sOkText,
                                   Command okCommand = null,
                                   string sCancelText = null,
                                   Command cancelCommand = null)
        {
            var msgBox = new SfPopupLayout();
            msgBox.Closed += MsgBox_Closed;

            msgBox.PopupView.AcceptButtonText = sOkText;
            if (!String.IsNullOrEmpty(sCancelText))
            {
                msgBox.PopupView.AppearanceMode = AppearanceMode.TwoButton;
                msgBox.PopupView.DeclineButtonText = sCancelText;
            }

            if (okCommand != null)
                msgBox.PopupView.AcceptCommand = okCommand;

            if (cancelCommand != null)
                msgBox.PopupView.DeclineCommand = cancelCommand;

            msgBox.PopupView.PopupStyle.CornerRadius = 10;
            msgBox.PopupView.ShowHeader = false;
            msgBox.PopupView.ShowCloseButton = false;
            msgBox.PopupView.AutoSizeMode = AutoSizeMode.Height;

            var contentTemplateView = new DataTemplate(() =>
            {
                var lbl = new Label();
                lbl.Margin = new Thickness(5, 10);
                lbl.Text = sMessage;
                lbl.LineBreakMode = LineBreakMode.WordWrap;
                lbl.WidthRequest = 260;

                var stack = new StackLayout();
                stack.Children.Add(lbl);
                return stack;
            });

            msgBox.PopupView.ContentTemplate = contentTemplateView;

            /// Makes the Message modal
            msgBox.StaysOpen = true;
            msgBox.IsOpen = true;
            msgBox.Show(false);
        }

        private void MsgBox_Closed(object sender, EventArgs e)
        {
            Debug.WriteLine("Demo page message box was closed");
        }
    }
}